Index: inteltool-ich5/inteltool.c
===================================================================
--- inteltool-ich5/inteltool.c	(revision 3330)
+++ inteltool-ich5/inteltool.c	(working copy)
@@ -38,10 +38,12 @@
 #define PCI_DEVICE_ID_INTEL_ICH0	0x2420
 #define PCI_DEVICE_ID_INTEL_ICH4	0x24c0
 #define PCI_DEVICE_ID_INTEL_ICH4M	0x24cc
+#define PCI_DEVICE_ID_INTEL_ICH5	0x24d0
 #define PCI_DEVICE_ID_INTEL_ICH7DH	0x27b0
 #define PCI_DEVICE_ID_INTEL_ICH7	0x27b8
 #define PCI_DEVICE_ID_INTEL_ICH7M	0x27b9
 #define PCI_DEVICE_ID_INTEL_ICH7MDH	0x27bd
+#define PCI_DEVICE_ID_INTEL_82865G	0x2570
 #define PCI_DEVICE_ID_INTEL_82945GM	0x27a0
 
 static const struct {
@@ -49,10 +51,12 @@
 	char *name;
 } supported_chips_list[] = {
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_82945GM, "i945GM" },
+	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_82865G, "i865G" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH7MDH, "ICH7-M DH" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH7M, "ICH7-M" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH7, "ICH7" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH7DH, "ICH7DH" },
+	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH5, "ICH5" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH4M, "ICH4-M" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH4, "ICH4" },
 	{ PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_ICH0, "ICH0" },
@@ -105,6 +109,23 @@
 	{ 0x3C, 4, "RESERVED" }
 };
 
+static const io_register_t ich5_gpio_registers[] = {
+       { 0x00, 4, "GPIO_USE_SEL" },
+       { 0x04, 4, "GP_IO_SEL" },
+       { 0x08, 4, "RESERVED" },
+       { 0x0c, 4, "GP_LVL" },
+       { 0x10, 4, "RESERVED" },
+       { 0x14, 4, "GPO_TTL" },
+       { 0x18, 4, "GPO_BLINK" },
+       { 0x1c, 4, "RESERVED" },
+       { 0x20, 4, "RESERVED" }, /* 0x20: 20h-2bh */
+       { 0x24, 4, "RESERVED" },
+       { 0x28, 4, "RESERVED" },
+       { 0x2c, 4, "GPI_INV" },
+       { 0x30, 4, "GPIO_USE_SEL2" },
+       { 0x34, 4, "GP_IO_SEL2" },
+       { 0x38, 4, "GP_LVL2" }
+};
 static const io_register_t ich7_gpio_registers[] = {
 	{ 0x00, 4, "GPIO_USE_SEL" },
 	{ 0x04, 4, "GP_IO_SEL" },
@@ -141,6 +162,11 @@
 		gpio_registers = ich7_gpio_registers;
 		size = ARRAY_SIZE(ich7_gpio_registers);
 		break;
+	case PCI_DEVICE_ID_INTEL_ICH5:
+		gpiobase = pci_read_word(sb, 0x58) & 0xfffc;
+		gpio_registers = ich5_gpio_registers;
+		size = ARRAY_SIZE(ich5_gpio_registers);
+		break;
 	case PCI_DEVICE_ID_INTEL_ICH4:
 	case PCI_DEVICE_ID_INTEL_ICH4M:
 		gpiobase = pci_read_word(sb, 0x58) & 0xfffc;
@@ -248,6 +274,9 @@
 	case PCI_DEVICE_ID_INTEL_ICH7MDH:
 		pmbase = pci_read_word(sb, 0x40) & 0xfffc;
 		break;
+	case PCI_DEVICE_ID_INTEL_ICH5:
+		pmbase = pci_read_word(sb, 0x40) & 0xfffc;
+		break;
 	case 0x1234: // Dummy for non-existent functionality
 		printf("This southbridge does not have PMBASE.\n");
 		return 1;
